@@ -1,6 +1,5 @@
-//
 // Windowmenu.cc for Blackbox - an X11 Window manager
-// Copyright (c) 1997, 1998 by Brad Hughes, bhughes@tcac.net
+// Copyright (c) 1997 - 1999 by Brad Hughes, bhughes@tcac.net
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -19,13 +18,13 @@
 // (See the included file COPYING / GPL-2.0)
 //
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
+#ifndef   _GNU_SOURCE
+#define   _GNU_SOURCE
+#endif // _GNU_SOURCE
 
-#ifdef HAVE_CONFIG_H
+#ifdef    HAVE_CONFIG_H
 #  include "../config.h"
-#endif
+#endif // HAVE_CONFIG_H
 
 #include "blackbox.hh"
 #include "Screen.hh"
@@ -33,9 +32,9 @@
 #include "Windowmenu.hh"
 #include "Workspace.hh"
 
-#if STDC_HEADERS
+#ifdef    STDC_HEADERS
 #  include <string.h>
-#endif
+#endif // STDC_HEADERS
 
 
 Windowmenu::Windowmenu(BlackboxWindow *win, Blackbox *bb) :
@@ -51,18 +50,17 @@ Windowmenu::Windowmenu(BlackboxWindow *win, Blackbox *bb) :
   sendToMenu = new SendtoWorkspaceMenu(win, bb);
   insert("Send To ...", sendToMenu);
   if (window->hasTitlebar())
-    insert("(Un)Shade", Blackbox::B_WindowShade);
+    insert("(Un)Shade", BScreen::WindowShade);
   if (window->isIconifiable())
-    insert("Iconify", Blackbox::B_WindowIconify);
+    insert("Iconify", BScreen::WindowIconify);
   if (window->isMaximizable())
-    insert("(Un)Maximize", Blackbox::B_WindowMaximize);  
-  insert("Raise", Blackbox::B_WindowRaise);
-  insert("Lower", Blackbox::B_WindowLower);
-  insert("(Un)Stick", Blackbox::B_WindowStick);
+    insert("(Un)Maximize", BScreen::WindowMaximize);  
+  insert("Raise", BScreen::WindowRaise);
+  insert("Lower", BScreen::WindowLower);
+  insert("(Un)Stick", BScreen::WindowStick);
+  insert("Kill Client", BScreen::WindowKill);
   if (window->isClosable())
-    insert("Close", Blackbox::B_WindowClose);
-  else
-    insert("Kill Client", Blackbox::B_WindowKill);
+    insert("Close", BScreen::WindowClose);
   
   update();
 }
@@ -77,44 +75,44 @@ void Windowmenu::itemSelected(int button, int index) {
   BasemenuItem *item = find(index);
     
   switch (item->function()) {
-  case Blackbox::B_WindowShade:
+  case BScreen::WindowShade:
     hide();
     window->shade();
     break;
       
-  case Blackbox::B_WindowIconify:
+  case BScreen::WindowIconify:
     hide();
     window->iconify();
     break;
       
-  case Blackbox::B_WindowMaximize:
+  case BScreen::WindowMaximize:
     hide();
     window->maximize((unsigned int) button);
     break;
       
-  case Blackbox::B_WindowClose:
+  case BScreen::WindowClose:
     hide();
     window->close();
     break;
       
-  case Blackbox::B_WindowRaise:
+  case BScreen::WindowRaise:
     hide();
     screen->getWorkspace(window->getWorkspaceNumber())->raiseWindow(window);
     break;
     
-  case Blackbox::B_WindowLower:
+  case BScreen::WindowLower:
     hide();
     screen->getWorkspace(window->getWorkspaceNumber())->lowerWindow(window);
     break;
 
-  case Blackbox::B_WindowStick:
+  case BScreen::WindowStick:
     hide();
     window->stick();
     break;
 
-  case Blackbox::B_WindowKill:
+  case BScreen::WindowKill:
     hide();
-    XKillClient(screen->getDisplay(), window->getClientWindow());
+    XKillClient(screen->getDisplay()->getDisplay(), window->getClientWindow());
     break;
   }
 }
@@ -132,18 +130,18 @@ void Windowmenu::setClosable(void) {
 
   for (i = 0; i < n; i++) {
     BasemenuItem *item = find(i);
-    if ((item->function() == Blackbox::B_WindowKill) ||
-	(item->function() == Blackbox::B_WindowClose)) {
+
+    if (item && (item->function() == BScreen::WindowClose)) {
       remove(i);
-      
-      if (window->isClosable())
-	insert("Close", Blackbox::B_WindowClose);
-      else
-	insert("Kill Client", Blackbox::B_WindowKill);
-      
-      update();
+
+      break;
     }
   }
+
+  if (window->isClosable())
+    insert("Close", BScreen::WindowClose);
+      
+  update();
 }
 
 
@@ -162,14 +160,16 @@ SendtoWorkspaceMenu::SendtoWorkspaceMenu(BlackboxWindow *win, Blackbox *bb) :
 
 void SendtoWorkspaceMenu::itemSelected(int button, int index) {
   if (button == 1) {
-    if ((index) <= screen->getCount())
-      if ((index) != screen->getCurrentWorkspaceID()) {
+    if ((index) <= screen->getCount()) {
+      if ((index) != screen->getCurrentWorkspaceID()) {	
 	screen->getWorkspace(window->getWorkspaceNumber())->
 	  removeWindow(window);
 	screen->getWorkspace(index)->addWindow(window);
+	
 	if (window->isStuck()) window->stick();
 	window->withdraw();
       }
+    }
   } else
     update();
 }
